function [ revisedpath ] = extendpath(guesspath)
% extendpath.m
% This m file iterates on the 2nd-order difference equation for output
% using a guess path to insert a value for the future level of output. The
% guess path, called guesspath, is inserted in as an input into 
% the function. The function is called from main.m

% The global statement is used to pass some information into the function
% from the main program. The function outputs the variable revisepath, 
% which contains the revised time path for output.

global g h i ostar T

revisedpath = zeros(T,1); % Starting level of output is zero.
revisedpath(T,1) = ostar; % Terminal output is the steady state level. 

    
% Iterate on difference equation starting from period 2 using starting
% value for the first period. There is no need to solve for the last 
% period output level since this taken to be the steady state level of
% output.

    for t=2:T-1
    revisedpath(t,1) = g + h*revisedpath(t-1,1) + i*guesspath(t+1,1);
    % Note that the starting value for output or revisedpath(1,1) = 0
    % Likewise, the terminal value, or revisedpath(T,1), is equal to 
    % ostar.
    end

end

