function [ zero ] = multshooting(o2)
% multshooting.m
% This m file solves for the terminal level of output by solving the 2nd
% order difference equation by making a guess for the second starting value
% for output. This function is called from main.m

% The global statement is used to pass some information into the function
% from the main program. The variable ovecms, which contains the time path
% for output is also passed back into main.m

global d e f ostar ovecms T

ovecms(2,1) = o2;             % Guess for second-period output
    
% Iterate on difference equation starting from period 3 using starting
% values for the first two periods for output

    for t=3:T
    ovecms(t,1) = d + e*ovecms(t-1,1) + f*ovecms(t-2,1);
    % Note that the starting value for output, ovecms(1,1) = 0
    % Likewise, the second starting value, ovecms(2,1), is equal to the 
    % guess
    end
    
% Examine the difference between the terminal level of output and the
% steady state level of output

zero = ostar - ovecms(T,1);
end

